@@ -5,7 +5,7 @@ package Dist::Zilla::PERLSRVDE;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.0'; # VERSION
+our $VERSION = '1.0.1'; # VERSION
 
 1;
 
@@ -21,18 +21,18 @@ Dist::Zilla::PERLSRVDE - A dummy module for this namespace
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 DESCRIPTION
 
 This is a collection of L<Dist::Zilla> related modules
-used at L<https://perl-services.de|Perl-Services.de>.
+used at L<Perl-Services.de|https://perl-services.de>.
 
 =head1 MODULES
 
 =head2 Dist::Zilla::PluginBundle::PERLSRVDE
 
-This is the L<Dist::Zilla::PluginBundle::PERLSRVDE|PluginBundle>
+This is the L<PluginBundle|Dist::Zilla::PluginBundle::PERLSRVDE>
 to include the Plugins we usually use.
 
 =head1 AUTHOR
